=======
History
=======

1.2.1 (12th July 2018)
----------------------

* Decode report download to remove BOM from Python 3

1.2.0 (5th Feb 2018)
--------------------

* Fixed issue with report downloads just being named the plan instead of a CSV name

0.16.0 (20th Jan 2017)
----------------------

* Added string representations for the core models

0.15.0 (19th Jan 2017)
----------------------

* Add support for filtering invitations

0.14.0 (17th Jan 2017)
----------------------

* Add support for generating the invite URL from an invite object using :class:`Invite`.`generate_url()`

0.13.0 (21st Dec 2016)
----------------------

* Add support for cancelling invitations

0.12.0 (20th Dec 2016)
----------------------

* Fix bug in initialization of invite objects

0.11.0 (20th Dec 2016)
----------------------

* Provide the error message from the Pluralsight API on non-20x responses


0.10.0 (2016-12-12)
------------------

* First stable release on PyPI.
* Support for models, invites, users and reports
